Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSergey Sharybin <sergey.vfx@gmail.com>2012-05-29 18:55:01 +0400
committerSergey Sharybin <sergey.vfx@gmail.com>2012-05-29 18:55:01 +0400
commitec4f6750557218be262cacea53ef4cb0ccaa0671 (patch)
tree433e584317dd7ad4abd04c62ca122d2244349112 /source/blender/compositor/operations
parentb63a2be5c16d9c0c728cf4e07dc565267b9d2a47 (diff)
Fixed stupid typo: dispill vs. despill
Diffstat (limited to 'source/blender/compositor/operations')
-rw-r--r--source/blender/compositor/operations/COM_KeyingDespillOperation.cpp (renamed from source/blender/compositor/operations/COM_KeyingDispillOperation.cpp)16
-rw-r--r--source/blender/compositor/operations/COM_KeyingDespillOperation.h (renamed from source/blender/compositor/operations/COM_KeyingDispillOperation.h)14
2 files changed, 15 insertions, 15 deletions
diff --git a/source/blender/compositor/operations/COM_KeyingDispillOperation.cpp b/source/blender/compositor/operations/COM_KeyingDespillOperation.cpp
index 5f4eaf3148d..b7fd2772729 100644
--- a/source/blender/compositor/operations/COM_KeyingDispillOperation.cpp
+++ b/source/blender/compositor/operations/COM_KeyingDespillOperation.cpp
@@ -21,7 +21,7 @@
* Sergey Sharybin
*/
-#include "COM_KeyingDispillOperation.h"
+#include "COM_KeyingDespillOperation.h"
#include "MEM_guardedalloc.h"
@@ -40,31 +40,31 @@ static int get_pixel_primary_channel(float *pixel)
return 2;
}
-KeyingDispillOperation::KeyingDispillOperation(): NodeOperation()
+KeyingDespillOperation::KeyingDespillOperation(): NodeOperation()
{
this->addInputSocket(COM_DT_COLOR);
this->addInputSocket(COM_DT_COLOR);
this->addOutputSocket(COM_DT_COLOR);
- this->dispillFactor = 0.5f;
+ this->despillFactor = 0.5f;
this->pixelReader = NULL;
this->screenReader = NULL;
}
-void KeyingDispillOperation::initExecution()
+void KeyingDespillOperation::initExecution()
{
this->pixelReader = this->getInputSocketReader(0);
this->screenReader = this->getInputSocketReader(1);
}
-void KeyingDispillOperation::deinitExecution()
+void KeyingDespillOperation::deinitExecution()
{
this->pixelReader = NULL;
this->screenReader = NULL;
}
-void KeyingDispillOperation::executePixel(float *color, float x, float y, PixelSampler sampler, MemoryBuffer *inputBuffers[])
+void KeyingDespillOperation::executePixel(float *color, float x, float y, PixelSampler sampler, MemoryBuffer *inputBuffers[])
{
float pixelColor[4];
float screenColor[4];
@@ -83,7 +83,7 @@ void KeyingDispillOperation::executePixel(float *color, float x, float y, PixelS
color[2] = pixelColor[2];
color[3] = pixelColor[3];
- if (this->dispillFactor * amount > 0) {
- color[screen_primary_channel] = pixelColor[screen_primary_channel] - this->dispillFactor * amount;
+ if (this->despillFactor * amount > 0) {
+ color[screen_primary_channel] = pixelColor[screen_primary_channel] - this->despillFactor * amount;
}
}
diff --git a/source/blender/compositor/operations/COM_KeyingDispillOperation.h b/source/blender/compositor/operations/COM_KeyingDespillOperation.h
index a918a918381..92a1415a1f0 100644
--- a/source/blender/compositor/operations/COM_KeyingDispillOperation.h
+++ b/source/blender/compositor/operations/COM_KeyingDespillOperation.h
@@ -21,27 +21,27 @@
* Sergey Sharybin
*/
-#ifndef _COM_KeyingDispillOperation_h
-#define _COM_KeyingDispillOperation_h
+#ifndef _COM_KeyingDespillOperation_h
+#define _COM_KeyingDespillOperation_h
#include "COM_NodeOperation.h"
/**
* Class with implementation of keying dispill node
*/
-class KeyingDispillOperation : public NodeOperation {
+class KeyingDespillOperation : public NodeOperation {
protected:
SocketReader *pixelReader;
SocketReader *screenReader;
- float dispillFactor;
+ float despillFactor;
public:
- KeyingDispillOperation();
+ KeyingDespillOperation();
void initExecution();
void deinitExecution();
- void setDispillFactor(float value) {this->dispillFactor = value;}
+ void setDespillFactor(float value) {this->despillFactor = value;}
void executePixel(float *color, float x, float y, PixelSampler sampler, MemoryBuffer *inputBuffers[]);
};
@@ -21,27 +21,27 @@
#include "COM_NodeOperation.h"
/**
- * Class with implementation of keying dispill node
+ * Class with implementation of keying despill node
*/